@@ -39,7 +39,7 @@ hcp_garch <- function(sw_size = 5) {
 #'@importFrom stats residuals
 #'@importFrom rugarch ugarchspec
 #'@importFrom rugarch ugarchfit
-#'@export
+#'@exportS3Method detect hcp_garch
 detect.hcp_garch <- function(obj, serie, ...) {
   linreg <- function(serie) {
     data <- data.frame(t = 1:length(serie), x = serie)
@@ -71,7 +71,7 @@ detect.hcp_garch <- function(obj, serie, ...) {
   cp[1:obj$sw_size] <- FALSE
   cp <- c(rep(FALSE, length(y)-length(u)), cp)
 
-  detection <- obj$har_restore_refs(obj, change_points = cp)
+  detection <- obj$har_restore_refs(obj, change_points = cp, res = u)
 
   return(detection)
 }
